"""WX colors"""

import wx

MAGENTA = wx.Colour(255, 102, 0)
GREEN = wx.Colour(68, 170, 0)
RED = wx.Colour(212, 0, 0)
BLUE = wx.BLUE
DARK_GREY = wx.Colour(33, 33, 33)
LIGHT_GREY = wx.Colour(210, 210, 210)
WHITE = wx.Colour(255, 255, 255)
